@@ -112,11 +112,14 @@ func commentGitHubCmd(ctx *config.RunContext) *cobra.Command {
 			})
 			var policyFailure output.PolicyCheckFailures
 			var guardrailFailure output.GuardrailFailures
+			var tagPolicyFailure *output.TagPolicyCheck
 			if err != nil {
 				if v, ok := err.(output.PolicyCheckFailures); ok {
 					policyFailure = v
 				} else if v, ok := err.(output.GuardrailFailures); ok {
 					guardrailFailure = v
+				} else if v, ok := err.(output.TagPolicyCheck); ok {
+					tagPolicyFailure = &v
 				} else {
 					return err
 				}
@@ -155,6 +158,10 @@ func commentGitHubCmd(ctx *config.RunContext) *cobra.Command {
 				cmd.Printf("\n")
 				return guardrailFailure
 			}
+			if tagPolicyFailure != nil {
+				cmd.Printf("\n")
+				return tagPolicyFailure
+			}
 
 			return nil
 		},
