@@ -110,7 +110,7 @@ func NewEvaluator(
 	logger *logrus.Entry,
 ) *Evaluator {
 	ctx := NewContext(&hcl.EvalContext{
-		Functions: expFunctions(module.RootPath, logger),
+		Functions: ExpFunctions(module.RootPath, logger),
 	}, nil, logger)
 
 	if visitedModules == nil {
@@ -727,6 +727,9 @@ func (e *Evaluator) evaluateProvider(b *Block, values map[string]cty.Value) cty.
 	}
 
 	ob := v.AsValueMap()
+	if ob == nil {
+		ob = make(map[string]cty.Value)
+	}
 	ob[str] = b.Values()
 	return cty.ObjectVal(ob)
 }
@@ -914,9 +917,9 @@ func (e *Evaluator) loadModules(lastContext hcl.EvalContext) {
 	}
 }
 
-// expFunctions returns the set of functions that should be used to when evaluating
+// ExpFunctions returns the set of functions that should be used to when evaluating
 // expressions in the receiving scope.
-func expFunctions(baseDir string, logger *logrus.Entry) map[string]function.Function {
+func ExpFunctions(baseDir string, logger *logrus.Entry) map[string]function.Function {
 	return map[string]function.Function{
 		"abs":              stdlib.AbsoluteFunc,
 		"abspath":          funcs.AbsPathFunc,
@@ -962,7 +965,7 @@ func expFunctions(baseDir string, logger *logrus.Entry) map[string]function.Func
 		"indent":           stdlib.IndentFunc,
 		"index":            funcs.IndexFunc, // stdlib.IndexFunc is not compatible
 		"join":             stdlib.JoinFunc,
-		"jsondecode":       stdlib.JSONDecodeFunc,
+		"jsondecode":       funcs.JSONDecodeFunc,
 		"jsonencode":       stdlib.JSONEncodeFunc,
 		"keys":             stdlib.KeysFunc,
 		"length":           funcs.LengthFunc,
@@ -1020,7 +1023,7 @@ func expFunctions(baseDir string, logger *logrus.Entry) map[string]function.Func
 		"uuid":             funcs.UUIDFunc,
 		"uuidv5":           funcs.UUIDV5Func,
 		"values":           stdlib.ValuesFunc,
-		"yamldecode":       yaml.YAMLDecodeFunc,
+		"yamldecode":       funcs.YAMLDecodeFunc,
 		"yamlencode":       yaml.YAMLEncodeFunc,
 		"zipmap":           stdlib.ZipmapFunc,
 	}
