@@ -5,6 +5,7 @@ import (
 	"bytes"
 	"fmt"
 	"html/template"
+	"path/filepath"
 	"strings"
 
 	"github.com/shopspring/decimal"
@@ -20,7 +21,7 @@ func ToHTML(out Root, opts Options) ([]byte, error) {
 	var buf bytes.Buffer
 	bufw := bufio.NewWriter(&buf)
 
-	tmpl := template.New("base")
+	tmpl := template.New("html.tmpl")
 	tmpl.Funcs(sprig.FuncMap())
 	tmpl.Funcs(template.FuncMap{
 		"safeHTML": func(s interface{}) template.HTML {
@@ -57,7 +58,7 @@ func ToHTML(out Root, opts Options) ([]byte, error) {
 			return p.Metadata.WorkspaceLabel()
 		},
 	})
-	tmpl, err := tmpl.Parse(HTMLTemplate)
+	_, err := tmpl.ParseFS(templatesFS, filepath.Join("templates", "html.tmpl"))
 	if err != nil {
 		return []byte{}, err
 	}
