@@ -12,6 +12,7 @@ import (
 	"time"
 
 	"github.com/shopspring/decimal"
+	"github.com/tidwall/gjson"
 
 	"github.com/infracost/infracost/internal/schema"
 	"github.com/infracost/infracost/internal/ui"
@@ -28,6 +29,7 @@ type Root struct {
 	CloudURL             string           `json:"cloudUrl,omitempty"`
 	Currency             string           `json:"currency"`
 	Projects             Projects         `json:"projects"`
+	TagPolicies          []TagPolicy      `json:"tagPolicies,omitempty"`
 	TotalHourlyCost      *decimal.Decimal `json:"totalHourlyCost"`
 	TotalMonthlyCost     *decimal.Decimal `json:"totalMonthlyCost"`
 	PastTotalHourlyCost  *decimal.Decimal `json:"pastTotalHourlyCost"`
@@ -40,6 +42,33 @@ type Root struct {
 	IsCIRun              bool             `json:"-"`
 }
 
+// TagPolicy holds information if a given run has applicable tag policy checks.
+// This struct is returned from the tag policies API and used to create tag policy outputs.
+type TagPolicy struct {
+	Name        string              `json:"name"`
+	TagPolicyID string              `json:"tagPolicyId"`
+	Message     string              `json:"message"`
+	PrComment   bool                `json:"prComment"`
+	BlockPr     bool                `json:"blockPr"`
+	Resources   []TagPolicyResource `json:"resources"`
+}
+
+type TagPolicyResource struct {
+	Address              string                `json:"address"`
+	ResourceType         string                `json:"resourceType"`
+	Path                 string                `json:"path"`
+	Line                 int                   `json:"line"`
+	ProjectNames         []string              `json:"projectNames"`
+	MissingMandatoryTags []string              `json:"missingMandatoryTags"`
+	InvalidTags          []TagPolicyInvalidTag `json:"invalidTags"`
+}
+
+type TagPolicyInvalidTag struct {
+	Key         string   `json:"key"`
+	ValidValues []string `json:"validValues"`
+	ValidRegex  string   `json:"validRegex"`
+}
+
 type Project struct {
 	Name          string                  `json:"name"`
 	Metadata      *schema.ProjectMetadata `json:"metadata"`
@@ -78,12 +107,14 @@ func convertOutputResources(outResources []Resource) []*schema.Resource {
 	for i, resource := range outResources {
 		resources[i] = &schema.Resource{
 			Name:           resource.Name,
+			Metadata:       convertMetadata(resource.Metadata),
 			CostComponents: convertCostComponents(resource.CostComponents),
 			ActualCosts:    convertActualCosts(resource.ActualCosts),
 			SubResources:   convertOutputResources(resource.SubResources),
+			Tags:           resource.Tags,
 			HourlyCost:     resource.HourlyCost,
 			MonthlyCost:    resource.MonthlyCost,
-			ResourceType:   resource.ResourceType(),
+			ResourceType:   resource.ResourceType,
 		}
 	}
 
@@ -128,6 +159,18 @@ func convertActualCosts(outActualCosts []ActualCosts) []*schema.ActualCosts {
 	return actualCosts
 }
 
+func convertMetadata(metadata map[string]interface{}) map[string]gjson.Result {
+	result := make(map[string]gjson.Result)
+	for k, v := range metadata {
+		jsonBytes, err := json.Marshal(v)
+		if err == nil {
+			result[k] = gjson.ParseBytes(jsonBytes)
+		}
+	}
+
+	return result
+}
+
 type Projects []Project
 
 var exampleProjectsRegex = regexp.MustCompile(`^infracost\/(infracost\/examples|example-terraform)\/`)
@@ -205,6 +248,7 @@ type ActualCosts struct {
 
 type Resource struct {
 	Name           string                 `json:"name"`
+	ResourceType   string                 `json:"resourceType,omitempty"`
 	Tags           map[string]string      `json:"tags,omitempty"`
 	Metadata       map[string]interface{} `json:"metadata"`
 	HourlyCost     *decimal.Decimal       `json:"hourlyCost"`
@@ -214,16 +258,6 @@ type Resource struct {
 	SubResources   []Resource             `json:"subresources,omitempty"`
 }
 
-func (r Resource) ResourceType() string {
-	pieces := strings.Split(r.Name, ".")
-
-	if len(pieces) >= 2 {
-		return pieces[len(pieces)-2]
-	}
-
-	return r.Name
-}
-
 type Summary struct {
 	TotalResources            *int `json:"totalResources,omitempty"`
 	TotalDetectedResources    *int `json:"totalDetectedResources,omitempty"`
@@ -256,6 +290,7 @@ type Options struct {
 	Fields            []string
 	IncludeHTML       bool
 	PolicyChecks      PolicyCheck
+	TagPolicyCheck    TagPolicyCheck
 	GuardrailCheck    GuardrailCheck
 	diffMsg           string
 	CurrencyFormat    string
@@ -292,6 +327,87 @@ func (p PolicyCheckFailures) Error() string {
 	return out.String()
 }
 
+// TagPolicyCheck holds information if a given run has any tag policies enabled.
+// This struct is used in templates to create useful cost policy outputs.
+type TagPolicyCheck struct {
+	FailingTagPolicies []TagPolicy
+	WarningTagPolicies []TagPolicy
+	PassingTagPolicies []TagPolicy
+}
+
+func NewTagPolicyChecks(tps []TagPolicy) TagPolicyCheck {
+	tpc := TagPolicyCheck{}
+
+	for _, tp := range tps {
+		if !tp.PrComment {
+			continue
+		}
+
+		if len(tp.Resources) == 0 {
+			tpc.PassingTagPolicies = append(tpc.PassingTagPolicies, tp)
+			continue
+		}
+
+		if tp.BlockPr {
+			tpc.FailingTagPolicies = append(tpc.FailingTagPolicies, tp)
+		} else {
+			tpc.WarningTagPolicies = append(tpc.WarningTagPolicies, tp)
+		}
+	}
+
+	return tpc
+}
+
+func (tpc TagPolicyCheck) Error() string {
+	if len(tpc.FailingTagPolicies) == 0 {
+		return ""
+	}
+
+	out := bytes.NewBuffer([]byte("Tag policy check failed:\n"))
+
+	for _, tp := range tpc.FailingTagPolicies {
+		fmt.Fprintf(out, "\n  %s: %s\n", tp.Name, tp.Message)
+		for _, r := range tp.Resources {
+			fmt.Fprintf(out, "    %s in project(s) %s\n", r.Address, strings.Join(r.ProjectNames, ", "))
+			for _, f := range r.Failures() {
+				fmt.Fprintf(out, "    - %s\n", f)
+			}
+		}
+	}
+
+	return out.String()
+}
+
+func (r TagPolicyResource) Failures() []string {
+	var f []string
+	if len(r.MissingMandatoryTags) > 0 {
+		var tags []string
+		for i, tag := range r.MissingMandatoryTags {
+			if i > 1 && i == len(r.MissingMandatoryTags) {
+				tags = append(tags, fmt.Sprintf("and \"%s\"", tag))
+			} else {
+				tags = append(tags, fmt.Sprintf("\"%s\"", tag))
+			}
+		}
+		f = append(f, fmt.Sprintf("should have mandatory tags: %s", strings.Join(tags, ", ")))
+	}
+
+	for _, invalidTag := range r.InvalidTags {
+		if len(invalidTag.ValidValues) > 0 {
+			var validValues []string
+			for _, value := range invalidTag.ValidValues {
+				validValues = append(validValues, fmt.Sprintf("\"%s\"", value))
+			}
+			f = append(f, fmt.Sprintf("should have a valid value for \"%s\" tag: %s", invalidTag.Key, strings.Join(validValues, ", ")))
+		}
+		if invalidTag.ValidRegex != "" {
+			f = append(f, fmt.Sprintf("should have a valid value for \"%s\" tag: must match regex <code>%s</code>", invalidTag.Key, invalidTag.ValidRegex))
+		}
+	}
+
+	return f
+}
+
 // GuardrailCheck holds information if a given run has applicable guardrail checks.
 // This struct is used to create guardrail outputs.
 type GuardrailCheck struct {
@@ -492,6 +608,7 @@ func outputResource(r *schema.Resource) Resource {
 
 	return Resource{
 		Name:           r.Name,
+		ResourceType:   r.ResourceType,
 		Metadata:       metadata,
 		Tags:           r.Tags,
 		HourlyCost:     r.HourlyCost,
