@@ -1,6 +1,8 @@
 package terraform
 
 import (
+	"crypto/sha256"
+	"encoding/hex"
 	"encoding/json"
 	"flag"
 	"fmt"
@@ -11,11 +13,14 @@ import (
 	"strings"
 	"sync"
 
+	jsoniter "github.com/json-iterator/go"
 	log "github.com/sirupsen/logrus"
 	"github.com/zclconf/go-cty/cty"
 	"github.com/zclconf/go-cty/cty/gocty"
 	ctyJson "github.com/zclconf/go-cty/cty/json"
 
+	"github.com/infracost/infracost/internal/apiclient"
+	"github.com/infracost/infracost/internal/clierror"
 	"github.com/infracost/infracost/internal/config"
 	"github.com/infracost/infracost/internal/hcl"
 	"github.com/infracost/infracost/internal/hcl/modules"
@@ -341,10 +346,18 @@ func (p *HCLProvider) Modules() []HCLProject {
 					fmt.Fprintf(os.Stderr, "Detected Terraform project at %s\n", ui.DisplayPath(parser.Path()))
 				}
 
-				module, err := parser.ParseDirectory()
+				module, modErr := parser.ParseDirectory()
+				if modErr != nil {
+					if v, ok := modErr.(*clierror.PanicError); ok {
+						err := apiclient.ReportCLIError(p.ctx.RunContext, v, false)
+						if err != nil {
+							p.logger.WithError(err).Debug("error sending unexpected runtime error")
+						}
+					}
+				}
 
 				mu.Lock()
-				mods = append(mods, HCLProject{Module: module, Error: err})
+				mods = append(mods, HCLProject{Module: module, Error: modErr})
 				mu.Unlock()
 			}
 		}()
@@ -474,6 +487,9 @@ func (p *HCLProvider) marshalModule(module *hcl.Module) ModuleOut {
 }
 
 func (p *HCLProvider) getResourceOutput(block *hcl.Block) ResourceOutput {
+	jsonValues := marshalAttributeValues(block.Type(), block.Values())
+	p.marshalBlock(block, jsonValues)
+
 	planned := ResourceJSON{
 		Address:       block.FullName(),
 		Mode:          "managed",
@@ -482,8 +498,11 @@ func (p *HCLProvider) getResourceOutput(block *hcl.Block) ResourceOutput {
 		Index:         block.Index(),
 		SchemaVersion: 0,
 		InfracostMetadata: map[string]interface{}{
-			"filename": block.Filename,
-			"calls":    block.CallDetails(),
+			"filename":  block.Filename,
+			"startLine": block.StartLine,
+			"endLine":   block.EndLine,
+			"calls":     block.CallDetails(),
+			"checksum":  generateChecksum(jsonValues),
 		},
 	}
 
@@ -499,9 +518,6 @@ func (p *HCLProvider) getResourceOutput(block *hcl.Block) ResourceOutput {
 		},
 	}
 
-	jsonValues := marshalAttributeValues(block.Type(), block.Values())
-	p.marshalBlock(block, jsonValues)
-
 	planned.Values = jsonValues
 	changes.Change.After = jsonValues
 
@@ -600,6 +616,28 @@ func (p *HCLProvider) countReferences(block *hcl.Block) *countExpression {
 	return nil
 }
 
+var ignoredAttrs = map[string]bool{"arn": true, "id": true, "name": true, "self_link": true}
+var checksumMarshaller = jsoniter.ConfigCompatibleWithStandardLibrary
+
+func generateChecksum(value map[string]interface{}) string {
+	filtered := make(map[string]interface{})
+	for k, v := range value {
+		if !ignoredAttrs[k] {
+			filtered[k] = v
+		}
+	}
+
+	serialized, err := checksumMarshaller.Marshal(filtered)
+	if err != nil {
+		return ""
+	}
+
+	h := sha256.New()
+	h.Write(serialized)
+
+	return hex.EncodeToString(h.Sum(nil))
+}
+
 func blockToReferences(block *hcl.Block) map[string]interface{} {
 	expressionValues := make(map[string]interface{})
 
