@@ -30,6 +30,7 @@ import (
 	"github.com/pkg/errors"
 	log "github.com/sirupsen/logrus"
 	"github.com/zclconf/go-cty/cty"
+	"github.com/zclconf/go-cty/cty/function"
 	"github.com/zclconf/go-cty/cty/gocty"
 	ctyJson "github.com/zclconf/go-cty/cty/json"
 
@@ -313,7 +314,6 @@ func (p *TerragruntHCLProvider) prepWorkingDirs() ([]*terragruntWorkingDirInfo,
 	var workingDirsToEstimate []*terragruntWorkingDirInfo
 
 	tgLog := p.logger.WithFields(log.Fields{"library": "terragrunt"})
-
 	terragruntOptions := &tgoptions.TerragruntOptions{
 		TerragruntConfigPath:       terragruntConfigPath,
 		Logger:                     tgLog,
@@ -350,6 +350,14 @@ func (p *TerragruntHCLProvider) prepWorkingDirs() ([]*terragruntWorkingDirInfo,
 
 			return
 		},
+		Functions: func(baseDir string) map[string]function.Function {
+			funcs := hcl.ExpFunctions(baseDir, p.logger)
+
+			funcs["run_cmd"] = mockSliceFuncStaticReturn(cty.StringVal("mock-run_cmd"))
+			funcs["sops_decrypt_file"] = mockSliceFuncStaticReturn(cty.StringVal("mock"))
+
+			return funcs
+		},
 		Parallelism: 1,
 	}
 
@@ -1052,7 +1060,10 @@ func (p *TerragruntHCLProvider) downloadTerraformSourceIfNecessary(terraformSour
 		return err
 	}
 
-	currentVersion := terraformSource.EncodeSourceVersion()
+	currentVersion, err := terraformSource.EncodeSourceVersion()
+	if err != nil {
+		return fmt.Errorf("could not encode source version: %w", err)
+	}
 	// if source versions are different, create file to run init
 	// https://github.com/gruntwork-io/terragrunt/issues/1921
 	if previousVersion != currentVersion {
@@ -1151,9 +1162,12 @@ func (p *TerragruntHCLProvider) alreadyHaveLatestCode(terraformSource *tfsource.
 		return false, nil
 	}
 
-	currentVersion := terraformSource.EncodeSourceVersion()
-	previousVersion, err := p.readVersionFile(terraformSource)
+	currentVersion, err := terraformSource.EncodeSourceVersion()
+	if err != nil {
+		return false, fmt.Errorf("could not encode source version: %w", err)
+	}
 
+	previousVersion, err := p.readVersionFile(terraformSource)
 	if err != nil {
 		return false, err
 	}
@@ -1181,7 +1195,7 @@ func createStackForTerragruntConfigPaths(path string, terragruntConfigPaths []st
 		return nil, tgerrors.WithStackTrace(tgconfigstack.NoTerraformModulesFound)
 	}
 
-	modules, err := tgconfigstack.ResolveTerraformModules(terragruntConfigPaths, terragruntOptions, howThesePathsWereFound)
+	modules, err := tgconfigstack.ResolveTerraformModules(terragruntConfigPaths, terragruntOptions, nil, howThesePathsWereFound)
 	if err != nil {
 		return nil, err
 	}
@@ -1274,3 +1288,13 @@ func getCleanedTargetConfigPath(configPath string, workingPath string) string {
 	}
 	return util.CleanPath(targetConfig)
 }
+
+func mockSliceFuncStaticReturn(val cty.Value) function.Function {
+	return function.New(&function.Spec{
+		VarParam: &function.Parameter{Type: cty.String},
+		Type:     function.StaticReturnType(cty.String),
+		Impl: func(args []cty.Value, retType cty.Type) (cty.Value, error) {
+			return val, nil
+		},
+	})
+}
