@@ -245,6 +245,12 @@ func computeDiskCostComponent(region string, diskType string, diskSize float64,
 	case "pd-ssd":
 		diskTypeDesc = "/^SSD backed PD Capacity/"
 		diskTypeLabel = "SSD provisioned storage (pd-ssd)"
+	case "pd-extreme":
+		diskTypeDesc = "/^Extreme PD Capacity/"
+		diskTypeLabel = "Extreme provisioned storage (pd-extreme)"
+	case "hyperdisk-extreme":
+		diskTypeDesc = "/^Hyperdisk Extreme Capacity( in .*)?$/"
+		diskTypeLabel = "Hyperdisk provisioned storage (hyperdisk-extreme)"
 	}
 
 	size := decimalPtr(decimal.NewFromInt(instanceCount).Mul(decimal.NewFromFloat(diskSize)))
@@ -269,6 +275,36 @@ func computeDiskCostComponent(region string, diskType string, diskSize float64,
 	}
 }
 
+func computeDiskIOPSCostComponent(region string, diskType string, diskSize float64, instanceCount int64, iops int64) *schema.CostComponent {
+	var iopsTypeDesc string
+
+	switch diskType {
+	case "pd-extreme":
+		iopsTypeDesc = "/^Extreme PD IOPS/"
+	case "hyperdisk-extreme":
+		iopsTypeDesc = "/^Hyperdisk Extreme IOPS( in .*)?$/"
+	}
+
+	return &schema.CostComponent{
+		Name:            "Provisioned IOPS",
+		Unit:            "IOPS",
+		UnitMultiplier:  decimal.NewFromInt(1),
+		MonthlyQuantity: decimalPtr(decimal.NewFromInt(iops)),
+		ProductFilter: &schema.ProductFilter{
+			VendorName:    strPtr("gcp"),
+			Region:        strPtr(region),
+			Service:       strPtr("Compute Engine"),
+			ProductFamily: strPtr("Storage"),
+			AttributeFilters: []*schema.AttributeFilter{
+				{Key: "description", ValueRegex: strPtr(iopsTypeDesc)},
+			},
+		},
+		PriceFilter: &schema.PriceFilter{
+			EndUsageAmount: strPtr(""), // use the non-free tier
+		},
+	}
+}
+
 // guestAcceleratorCostComponent returns a cost component for Guest Accelerator usage for Compute resources.
 // Callers should be aware guestAcceleratorCostComponent returns nil if the provided guestAcceleratorType is not supported.
 func guestAcceleratorCostComponent(region string, purchaseOption string, guestAcceleratorType string, guestAcceleratorCount int64, instanceCount int64, monthlyHours *float64) *schema.CostComponent {
